==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/GeographicXYTriangulatingSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { GeographicMapSeriesHostDescription } from "./GeographicMapSeriesHostDescription";
import { markType } from "./type";
/**
 * @hidden
 */
export let GeographicXYTriangulatingSeriesDescription = /*@__PURE__*/ (() => {
    class GeographicXYTriangulatingSeriesDescription extends GeographicMapSeriesHostDescription {
        constructor() {
            super();
            this.c9 = null;
            this.c8 = null;
            this.da = null;
            this.db = null;
            this.dc = null;
            this.dd = null;
        }
        get_type() {
            return "GeographicXYTriangulatingSeries";
        }
        get longitudeMemberPath() {
            return this.c9;
        }
        set longitudeMemberPath(a) {
            this.c9 = a;
            this.e("LongitudeMemberPath");
        }
        get latitudeMemberPath() {
            return this.c8;
        }
        set latitudeMemberPath(a) {
            this.c8 = a;
            this.e("LatitudeMemberPath");
        }
        get trianglesSourceRef() {
            return this.da;
        }
        set trianglesSourceRef(a) {
            this.da = a;
            this.e("TrianglesSourceRef");
        }
        get triangleVertexMemberPath1() {
            return this.db;
        }
        set triangleVertexMemberPath1(a) {
            this.db = a;
            this.e("TriangleVertexMemberPath1");
        }
        get triangleVertexMemberPath2() {
            return this.dc;
        }
        set triangleVertexMemberPath2(a) {
            this.dc = a;
            this.e("TriangleVertexMemberPath2");
        }
        get triangleVertexMemberPath3() {
            return this.dd;
        }
        set triangleVertexMemberPath3(a) {
            this.dd = a;
            this.e("TriangleVertexMemberPath3");
        }
    }
    GeographicXYTriangulatingSeriesDescription.$t = /*@__PURE__*/ markType(GeographicXYTriangulatingSeriesDescription, 'GeographicXYTriangulatingSeriesDescription', GeographicMapSeriesHostDescription.$);
    return GeographicXYTriangulatingSeriesDescription;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/GeographicXYTriangulatingSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { GeographicMapSeriesHostDescription } from "./GeographicMapSeriesHostDescription";
import { markType } from "./type";
/**
 * @hidden
 */
export let GeographicXYTriangulatingSeriesDescription = /*@__PURE__*/ (() => {
    class GeographicXYTriangulatingSeriesDescription extends GeographicMapSeriesHostDescription {
        get_type() {
            return "GeographicXYTriangulatingSeries";
        }
        constructor() {
            super();
            this.e8 = null;
            this.e7 = null;
            this.e9 = null;
            this.fa = null;
            this.fb = null;
            this.fc = null;
        }
        get longitudeMemberPath() {
            return this.e8;
        }
        set longitudeMemberPath(a) {
            this.e8 = a;
            this.g("LongitudeMemberPath");
        }
        get latitudeMemberPath() {
            return this.e7;
        }
        set latitudeMemberPath(a) {
            this.e7 = a;
            this.g("LatitudeMemberPath");
        }
        get trianglesSourceRef() {
            return this.e9;
        }
        set trianglesSourceRef(a) {
            this.e9 = a;
            this.g("TrianglesSourceRef");
        }
        get triangleVertexMemberPath1() {
            return this.fa;
        }
        set triangleVertexMemberPath1(a) {
            this.fa = a;
            this.g("TriangleVertexMemberPath1");
        }
        get triangleVertexMemberPath2() {
            return this.fb;
        }
        set triangleVertexMemberPath2(a) {
            this.fb = a;
            this.g("TriangleVertexMemberPath2");
        }
        get triangleVertexMemberPath3() {
            return this.fc;
        }
        set triangleVertexMemberPath3(a) {
            this.fc = a;
            this.g("TriangleVertexMemberPath3");
        }
    }
    GeographicXYTriangulatingSeriesDescription.$t = /*@__PURE__*/ markType(GeographicXYTriangulatingSeriesDescription, 'GeographicXYTriangulatingSeriesDescription', GeographicMapSeriesHostDescription.$);
    return GeographicXYTriangulatingSeriesDescription;
})();
